/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *   * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.wso2.registry.app;

import org.apache.abdera.protocol.server.ServiceContext;
import org.apache.abdera.protocol.server.impl.AbstractSingletonProviderManager;
import org.apache.abdera.protocol.server.impl.DefaultServiceContext;
import org.apache.abdera.protocol.server.servlet.AbderaServlet;
import org.mortbay.jetty.Server;
import org.mortbay.jetty.servlet.Context;
import org.mortbay.jetty.servlet.ServletHolder;
import org.wso2.registry.RegistryConstants;
import org.wso2.registry.RegistryException;
import org.wso2.registry.jdbc.InMemoryJDBCRegistry;
import org.wso2.registry.jdbc.JDBCRegistry;
import org.wso2.registry.jdbc.JDBCRegistryTest;
import org.wso2.registry.jdbc.realm.InMemoryRegistryRealm;
import org.wso2.registry.jdbc.realm.RegistryRealm;

import javax.servlet.ServletException;
import java.net.URL;

//This test case run all the test cases that there in JDBCRegistry using RemoteRegistry

public class JettyBasedServerTest extends JDBCRegistryTest {
    private DefaultServiceContext abderaServiceContext;

    public void setUp() {
        try {
            if (registry == null) {
                initJetty();
                registry = new RemoteRegistry(new URL("http://localhost:8081/wso2registry/atom"));
            }
        } catch (Exception e) {
            fail("Failed to initialize the registry.");
        }
    }

    private void initJetty() throws Exception {
        abderaServiceContext = new RegistryAPPServiceContext();
        RegistryAPPTargetResolver resolver = new RegistryAPPTargetResolver();
        abderaServiceContext.setTargetResolver(resolver);
        AbstractSingletonProviderManager pm = new RegistryAtomProviderManager();
        abderaServiceContext.setProviderManager(pm);

        Server server = new Server(8081);
        Context root = new Context(server, "/wso2registry", Context.NO_SESSIONS);
        root.addServlet(new ServletHolder(new AbderaServlet() {

            @Override
            protected ServiceContext createServiceContext() {
                abderaServiceContext
                        .setDefaultProviderManager(RegistryAtomProviderManager.class.getName());
                abderaServiceContext
                        .setDefaultTargetResolver(RegistryAPPTargetResolver.class.getName());
                abderaServiceContext.init(getAbdera(), getProperties(getServletConfig()));
                JDBCRegistry jdbcRegistry;
                try {
                    RegistryRealm realm = new InMemoryRegistryRealm();
                    jdbcRegistry = new InMemoryJDBCRegistry(realm);
                    //Realm registryRealm =
                    //        RegistryRealmFactory.createInMemoryRegistryRealm();
                    //jdbcRegistry = new JDBCRegistry();
                    //jdbcRegistry.init(registryRealm);
                    System.getProperties().put(RegistryConstants.REGISTRY, jdbcRegistry);
                } catch (RegistryException e) {
                    e.printStackTrace();
                }
                return abderaServiceContext;
            }

            public void init() throws ServletException {
                super.init();
                System.out.println("done");
            }
        }), "/*");
        server.start();
    }
}
