/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.web.actions;

import org.wso2.registry.LogEntry;
import org.wso2.registry.secure.SecureRegistry;

import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.List;

public class RecentActivityAction extends AbstractRegistryAction {

    private String resourcePath;
    private String userName;
    private String fromDate;
    private String toDate;
    private String filter;

    private List activity = new ArrayList();

    public String execute(HttpServletRequest request) throws Exception {

        setRequest(request);

        if (resourcePath != null && resourcePath.equals("")) {
            resourcePath = null;
        }

        if (userName != null && userName.equals("")) {
            userName = null;
        }

        if (fromDate != null && fromDate.equals("")) {
            fromDate = null;
        }

        if (toDate != null && toDate.equals("")) {
            toDate = null;
        }

        if (filter == null) {
            filter = "1";
        }

        int filterValue = -1;
        if (filter.equals("resourceActions")) {
            filterValue = LogEntry.UPDATE;

        } else if (filter.equals("commentings")) {
            filterValue = LogEntry.COMMENT;

        } else if (filter.equals("taggings")) {
            filterValue = LogEntry.TAG;

        } else if (filter.equals("ratings")) {
            filterValue = LogEntry.RATING;

        }

        SecureRegistry secureRegistry = (SecureRegistry) getRegistry();
        LogEntry[] logs = secureRegistry.getLogs(resourcePath, filterValue, userName, null, null, true);

        for (int i = 0; i < logs.length; i++) {

            LogEntry logEntry = logs[i];

            if (logEntry.getAction() == LogEntry.UPDATE) {
                String entry = "<a href='/wso2registry/system/people/" + logEntry.getUserName() + "'>" + logEntry.getUserName() + "</a>" + " has updated the resource '" + "<a href='/wso2registry/web" + logEntry.getResourcePath() + "'>" + logEntry.getResourcePath() + "</a> on " + logEntry.getDate().toString() + ".";
                activity.add(entry);

            } else if (logEntry.getAction() == LogEntry.COMMENT) {
                String entry = "<a href='/wso2registry/system/people/" + logEntry.getUserName() + "'>" + logEntry.getUserName() + "</a>" + " has commented on resource '" + "<a href='/wso2registry/web" + logEntry.getResourcePath() + "'>" + logEntry.getResourcePath() + "</a> on " + logEntry.getDate().toString() + " with the following comment.<br/>" + logEntry.getActionData();
                activity.add(entry);

            } else if (logEntry.getAction() == LogEntry.TAG) {
                String entry = "<a href='/wso2registry/system/people/" + logEntry.getUserName() + "'>" + logEntry.getUserName() + "</a>" + " has tagged the resource '" + "<a href='/wso2registry/web" + logEntry.getResourcePath() + "'>" + logEntry.getResourcePath() + "</a> with tag '" + logEntry.getActionData() + "' on " + logEntry.getDate().toString() + ".";
                activity.add(entry);

            } else if (logEntry.getAction() == LogEntry.RATING) {
                String entry = "<a href='/wso2registry/system/people/" + logEntry.getUserName() + "'>" + logEntry.getUserName() + "</a>" + " has rated the resource '" + "<a href='/wso2registry/web" + logEntry.getResourcePath() + "'>" + logEntry.getResourcePath() + "</a> with rating " + logEntry.getActionData() + " on " + logEntry.getDate().toString() + ".";
                activity.add(entry);

            }
        }

        return SUCCESS;
    }

    public String getResourcePath() {
        return resourcePath;
    }

    public void setResourcePath(String resourcePath) {
        this.resourcePath = resourcePath;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getFromDate() {
        return fromDate;
    }

    public void setFromDate(String fromDate) {
        this.fromDate = fromDate;
    }

    public String getToDate() {
        return toDate;
    }

    public void setToDate(String toDate) {
        this.toDate = toDate;
    }

    public String getFilter() {
        return filter;
    }

    public void setFilter(String filter) {
        this.filter = filter;
    }

    public List getActivity() {
        return activity;
    }

    public void setActivity(List activity) {
        this.activity = activity;
    }
}